@@ -23,11 +23,19 @@ class Analyzer(object):
 
     @staticmethod
     def instance(lang=C.DEFAULT_LANG):
+        """Yields the Analyzer instance for a given language.
+        Args:
+            lang: The language of the wanted Analyzer object.
+        Return:
+            Analyzer instance.
+        """
         if Analyzer._instances.get(lang, None) == None:
             Analyzer._instances[lang] = Analyzer()
         return Analyzer._instances.get(lang)
 
     def __init__(self):
+        """Initializer.
+        """
         super(Analyzer, self).__init__()
         self._metrics = dict()
         self._rules = dict()
@@ -36,6 +44,10 @@ class Analyzer(object):
 
     @staticmethod
     def register(obj):
+        """Registers a given metric, rule, report or corpus with the Analyzer.
+        Args:
+            obj: A metric, rule, report or corpus object to register.
+        """
         if isinstance(obj, Metric) or \
            isinstance(obj, Rule) or \
            isinstance(obj, Report) or \
@@ -55,6 +67,15 @@ class Analyzer(object):
             self._corpora[obj.ID] = obj
 
     def get(self, metric=None, rule=None, report=None, corpus=None):
+        """Gets a given metric, rule, report or corpus by its ID.
+        Args:
+            metric: ID of the metric to get.
+            rule:   ID of the rule to get.
+            report: ID of the report to get.
+            corpus: ID of the corpus to get.
+        Return:
+            Metric, Rule, Report or Corpus object.
+        """
         if metric:
             return self._metrics.get(metric, None)
         elif rule:
@@ -65,18 +86,27 @@ class Analyzer(object):
             return self._corpora.get(corpus, None)
         return None
 
-    def metrics(self, lang=u""):
-        return {k: self._metrics[k] for k in self._metrics if self._metrics[k].language == lang}
+    def metrics(self):
+        """Yields all registered metrics.
+        """
+        return {k: self._metrics[k] for k in self._metrics}
+        #return {k: self._metrics[k] for k in self._metrics if self._metrics[k].language == lang}
 
-    def rules(self, lang=u""):
-        return {k: self._rules[k] for k in self._rules if self._rules[k].language == lang}
+    def rules(self):
+        """Yields all registered rules.
+        """
+        return {k: self._rules[k] for k in self._rules}
+        #return {k: self._rules[k] for k in self._rules if self._rules[k].language == lang}
 
-    def reports(self, lang=u""):
+    def reports(self):
+        """Yields all registered reports.
+        """
         #ret = list()
         #if lang != u"":
         #    ret.extend([r for r in self._reports.values() if r.language == lang])
         #return ret
-        return {k: self._reports[k] for k in self._reports if self._reports[k].language == lang}
+        return {k: self._reports[k] for k in self._reports}
+        #return {k: self._reports[k] for k in self._reports if self._reports[k].language == lang}
 
     def _languages(self, dictionary):
         """Returns a list of unique ISO 639-1 language codes denoting
@@ -95,6 +125,8 @@ class Analyzer(object):
             lang: List only reports of this language. Optional.
                   If omitted all reports of all languages are included
                   in the string.
+        Return:
+            A unicode string.
         """
         if len(self._reports) == 0:
             return u"No reports known to Confopy!"
@@ -104,7 +136,7 @@ class Analyzer(object):
         max_ID_len = 0
         if lang != u"":
             langs.append(lang)
-            report_IDs = sorted(self.reports(lang).keys())
+            report_IDs = sorted(self.reports().keys())
             max_ID_len = max([len(rID) for rID in report_IDs])
         else:
             langs.extend(self._languages(self._reports))
@@ -113,7 +145,7 @@ class Analyzer(object):
 
         for l in langs:
             buf.append(u'Reports for language "%s":' % (l, ))
-            report_IDs = sorted(self.reports(l).keys())
+            report_IDs = sorted(self.reports().keys())
             for report_ID in report_IDs:
                 report = self._reports.get(report_ID)
                 line = u"%s%s%s" % (Analyzer._PAD, report_ID.ljust(pad_width), report.brief)
@@ -126,12 +158,14 @@ class Analyzer(object):
         return u"\n".join(buf)
 
     def metriclist(self, lang=u""):
-        """
+        """Returns a pretty formatted list of metrics as a unicode string.
+        Return:
+            A unicode string.
         """
         buf = list()
         buf.append(u"Metrics for language \"" + lang + u"\":")
         keys = sorted(self._metrics.keys())
-        pad_width = reduce(max, [len(k) for k in keys]) + 2 * len(Analyzer._PAD)
+        pad_width = reduce(max, [len(k) for k in keys], 0) + 2 * len(Analyzer._PAD)
         for k in keys:
             metric = self._metrics[k]
             buf.append(u"%s%s%s" % (Analyzer._PAD, k.ljust(pad_width), metric.brief))
@@ -153,7 +187,7 @@ if __name__ == '__main__':
     analyzer.register(Report(u"test-fr1", u"fr"))
     analyzer.register(Report(u"test-fr2", u"fr"))
     analyzer.register(Report(u"test-fr3", u"fr"))
-    assert len(analyzer.reports(u"de")) == 2
+    assert len(analyzer.reports()) == 2
 
     print analyzer.reportlist(u"de")
     print analyzer.reportlist()
