@@ -75,6 +75,24 @@ def count_subsections(node):
     return len(subsections)
 
 def is_referenced(flt):
+    parent = flt.parent()
+    if parent is not None:
+        siblings = list()
+        children = parent.children()
+        for child in children:
+            if child.is_paragraph():
+                siblings.append(child)
+        para_texts = [sib.text for sib in siblings]
+        para_texts = u"".join(para_texts)
+
+        if flt.number != u"":
+            return flt.number in para_texts
+        flt_text = flt.text.strip().split(" ")
+        if len(flt_text) >= 2:
+            flt_text = flt_text[0].strip() + " " + flt_text[1].strip()
+            flt_text = flt_text.replace(u":", u"")
+            return flt_text in para_texts
+
     return False
 
 
@@ -110,7 +128,7 @@ def eval_doc(document, rules):
         para_rules = [r for r in rules if r.kind == RuleKind.PARAGRAPH]
         messages = _eval_rules(document, para_rules)
 
-    elif isinstance(document, Float):
+    elif document.is_float():
         float_rules = [r for r in rules if r.kind == RuleKind.FLOAT]
         messages = _eval_rules(document, float_rules)
 
