@@ -9,7 +9,7 @@ Description:
 from math import fsum
 
 from confopy.analysis import Metric, Analyzer, SpellChecker, NO_WORDS
-from pattern.de import lemma
+from pattern.de import lemma, tenses
 
 # General German metrics
 
@@ -160,12 +160,24 @@ class SimplePresentMetric(Metric):
         total_verbs = 0
         for w in tagged_words:
             if w[1] and w[1].startswith(u"V"):
-                if w[1].startswith(u"VVFIN") or\
-                   w[1].startswith(u"VAFIN") or\
-                   w[1].startswith(u"VVINF") or\
-                   w[1].startswith(u"VVIZU"): # beinhaltet noch vergangenheit!
-                    pres_verbs += 1
+                #if w[1].startswith(u"VVFIN") or\
+                #   w[1].startswith(u"VAFIN") or\
+                #   w[1].startswith(u"VVINF") or\
+                #   w[1].startswith(u"VVIZU"): # beinhaltet noch vergangenheit!
+                #    pres_verbs += 1
                 total_verbs += 1
+                tense = tenses(w[0])
+                if tense is not []:
+                    tense = [t[0] for t in tense]
+                    past_count = 0
+                    present_count = 0
+                    for t in tense:
+                        if t == "past":
+                            past_count += 1
+                        elif t == "present":
+                            present_count += 1
+                    if present_count > past_count:
+                        pres_verbs += 1
                 #print w
         if total_verbs > 0:
             return float(pres_verbs) / total_verbs
